Module blaxel.core.client.models.port
=====================================

Classes
-------

`Port(name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, protocol: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, target: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   A port for a resource
    
    Attributes:
        name (Union[Unset, str]): The name of the port
        protocol (Union[Unset, str]): The protocol of the port
        target (Union[Unset, int]): The target port of the port
    
    Method generated by attrs for class Port.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    `protocol: blaxel.core.client.types.Unset | str`
    :

    `target: blaxel.core.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :